@@ -10,7 +10,7 @@ import (
 	"github.com/anchore/grype/cmd/grype/cli/commands"
 	grypeHandler "github.com/anchore/grype/cmd/grype/cli/ui"
 	"github.com/anchore/grype/cmd/grype/internal/ui"
-	"github.com/anchore/grype/grype/vulnerability"
+	"github.com/anchore/grype/grype/db"
 	"github.com/anchore/grype/internal/bus"
 	"github.com/anchore/grype/internal/log"
 	"github.com/anchore/grype/internal/redact"
@@ -36,19 +36,19 @@ func create(id clio.Identification) (clio.Application, *cobra.Command) {
 		WithConfigInRootHelp().   // --help on the root command renders the full application config in the help text
 		WithUIConstructor(
 			// select a UI based on the logging configuration and state of stdin (if stdin is a tty)
-			func(cfg clio.Config) ([]clio.UI, error) {
+			func(cfg clio.Config) (*clio.UICollection, error) {
 				noUI := ui.None(cfg.Log.Quiet)
 				if !cfg.Log.AllowUI(os.Stdin) || cfg.Log.Quiet {
-					return []clio.UI{noUI}, nil
+					return clio.NewUICollection(noUI), nil
 				}
 
-				return []clio.UI{
+				return clio.NewUICollection(
 					ui.New(cfg.Log.Quiet,
 						grypeHandler.New(grypeHandler.DefaultHandlerConfig()),
 						syftHandler.New(syftHandler.DefaultHandlerConfig()),
 					),
 					noUI,
-				}, nil
+				), nil
 			},
 		).
 		WithInitializers(
@@ -106,5 +106,5 @@ func syftVersion() (string, any) {
 }
 
 func dbVersion() (string, any) {
-	return "Supported DB Schema", vulnerability.SchemaVersion
+	return "Supported DB Schema", db.SchemaVersion
 }
