@@ -199,8 +199,9 @@ func Test_NamespaceForDistro(t *testing.T) {
 		allDistros.Add(d.String())
 	}
 
-	// TODO: what do we do with mariner
+	// v3 and older schemas don't include these newer distros:
 	allDistros.Remove(distro.Mariner.String())
+	allDistros.Remove(distro.Azure.String())
 
 	for _, test := range tests {
 		name := fmt.Sprintf("%s:%s", test.dist, test.version)
@@ -417,6 +418,8 @@ func Test_NamespacesForLanguage(t *testing.T) {
 	allLanguages.Remove(string(syftPkg.CPP))
 	allLanguages.Remove(string(syftPkg.R))
 	allLanguages.Remove(string(syftPkg.Lua))
+	allLanguages.Remove(string(syftPkg.Swipl))
+	allLanguages.Remove(string(syftPkg.OCaml))
 
 	for _, test := range tests {
 		t.Run(string(test.language), func(t *testing.T) {
