@@ -21,7 +21,7 @@ type store struct {
 
 // New creates a new instance of the store.
 func New(dbFilePath string, overwrite bool) (v4.Store, error) {
-	db, err := gormadapter.Open(dbFilePath, overwrite)
+	db, err := gormadapter.Open(dbFilePath, gormadapter.WithTruncate(overwrite))
 	if err != nil {
 		return nil, err
 	}
@@ -265,8 +265,8 @@ func (s *store) AddVulnerabilityMatchExclusion(exclusions ...v4.VulnerabilityMat
 func (s *store) Close() {
 	s.db.Exec("VACUUM;")
 
-	sqlDB, err := s.db.DB()
-	if err != nil {
+	sqlDB, _ := s.db.DB()
+	if sqlDB != nil {
 		_ = sqlDB.Close()
 	}
 }
