@@ -2,8 +2,6 @@ package store
 
 import (
 	"encoding/json"
-	"io/ioutil"
-	"os"
 	"sort"
 	"testing"
 	"time"
@@ -30,13 +28,9 @@ func assertIDReader(t *testing.T, reader v4.IDReader, expected v4.ID) {
 }
 
 func TestStore_GetID_SetID(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -73,13 +67,9 @@ func assertVulnerabilityReader(t *testing.T, reader v4.VulnerabilityStoreReader,
 }
 
 func TestStore_GetVulnerability_SetVulnerability(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -280,13 +270,9 @@ type CustomMetadata struct {
 }
 
 func TestStore_GetVulnerabilityMetadata_SetVulnerabilityMetadata(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -754,12 +740,7 @@ func TestStore_MergeVulnerabilityMetadata(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			dbTempDir, err := ioutil.TempDir("", "grype-db-test-store")
-			if err != nil {
-				t.Fatalf("could not create temp file: %+v", err)
-			}
-			defer os.RemoveAll(dbTempDir)
-
+			dbTempDir := t.TempDir()
 			s, err := New(dbTempDir, true)
 			if err != nil {
 				t.Fatalf("could not create store: %+v", err)
@@ -1027,11 +1008,7 @@ func TestCvssScoresInMetadata(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			dbTempDir, err := ioutil.TempDir("", "grype-db-test-s")
-			if err != nil {
-				t.Fatalf("could not create temp file: %+v", err)
-			}
-			defer os.RemoveAll(dbTempDir)
+			dbTempDir := t.TempDir()
 
 			s, err := New(dbTempDir, true)
 			if err != nil {
@@ -1078,13 +1055,9 @@ func assertVulnerabilityMatchExclusionReader(t *testing.T, reader v4.Vulnerabili
 }
 
 func TestStore_GetVulnerabilityMatchExclusion_SetVulnerabilityMatchExclusion(t *testing.T) {
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s, err := New(dbTempFile.Name(), true)
+	s, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
@@ -1239,23 +1212,15 @@ func TestStore_GetVulnerabilityMatchExclusion_SetVulnerabilityMatchExclusion(t *
 
 func Test_DiffStore(t *testing.T) {
 	//GIVEN
-	dbTempFile, err := ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile := t.TempDir()
 
-	s1, err := New(dbTempFile.Name(), true)
+	s1, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
-	dbTempFile, err = ioutil.TempFile("", "grype-db-test-store")
-	if err != nil {
-		t.Fatalf("could not create temp file: %+v", err)
-	}
-	defer os.Remove(dbTempFile.Name())
+	dbTempFile = t.TempDir()
 
-	s2, err := New(dbTempFile.Name(), true)
+	s2, err := New(dbTempFile, true)
 	if err != nil {
 		t.Fatalf("could not create store: %+v", err)
 	}
