@@ -1,6 +1,8 @@
 package match
 
 import (
+	"regexp"
+
 	"github.com/bmatcuk/doublestar/v2"
 )
 
@@ -24,15 +26,17 @@ type IgnoreRule struct {
 	Package          IgnoreRulePackage `yaml:"package" json:"package" mapstructure:"package"`
 	VexStatus        string            `yaml:"vex-status" json:"vex-status" mapstructure:"vex-status"`
 	VexJustification string            `yaml:"vex-justification" json:"vex-justification" mapstructure:"vex-justification"`
+	MatchType        Type              `yaml:"match-type" json:"match-type" mapstructure:"match-type"`
 }
 
 // IgnoreRulePackage describes the Package-specific fields that comprise the IgnoreRule.
 type IgnoreRulePackage struct {
-	Name     string `yaml:"name" json:"name" mapstructure:"name"`
-	Version  string `yaml:"version" json:"version" mapstructure:"version"`
-	Language string `yaml:"language" json:"language" mapstructure:"language"`
-	Type     string `yaml:"type" json:"type" mapstructure:"type"`
-	Location string `yaml:"location" json:"location" mapstructure:"location"`
+	Name         string `yaml:"name" json:"name" mapstructure:"name"`
+	Version      string `yaml:"version" json:"version" mapstructure:"version"`
+	Language     string `yaml:"language" json:"language" mapstructure:"language"`
+	Type         string `yaml:"type" json:"type" mapstructure:"type"`
+	Location     string `yaml:"location" json:"location" mapstructure:"location"`
+	UpstreamName string `yaml:"upstream-name" json:"upstream-name" mapstructure:"upstream-name"`
 }
 
 // ApplyIgnoreRules iterates through the provided matches and, for each match,
@@ -137,6 +141,13 @@ func getIgnoreConditionsForRule(rule IgnoreRule) []ignoreCondition {
 		ignoreConditions = append(ignoreConditions, ifFixStateApplies(fs))
 	}
 
+	if upstreamName := rule.Package.UpstreamName; upstreamName != "" {
+		ignoreConditions = append(ignoreConditions, ifUpstreamPackageNameApplies(upstreamName))
+	}
+
+	if matchType := rule.MatchType; matchType != "" {
+		ignoreConditions = append(ignoreConditions, ifMatchTypeApplies(matchType))
+	}
 	return ignoreConditions
 }
 
@@ -158,9 +169,22 @@ func ifNamespaceApplies(namespace string) ignoreCondition {
 	}
 }
 
+func packageNameRegex(packageName string) (*regexp.Regexp, error) {
+	pattern := packageName
+	if packageName[0] != '$' || packageName[len(packageName)-1] != '^' {
+		pattern = "^" + packageName + "$"
+	}
+	return regexp.Compile(pattern)
+}
+
 func ifPackageNameApplies(name string) ignoreCondition {
+	pattern, err := packageNameRegex(name)
+	if err != nil {
+		return func(Match) bool { return false }
+	}
+
 	return func(match Match) bool {
-		return name == match.Package.Name
+		return pattern.MatchString(match.Package.Name)
 	}
 }
 
@@ -188,13 +212,35 @@ func ifPackageLocationApplies(location string) ignoreCondition {
 	}
 }
 
+func ifUpstreamPackageNameApplies(name string) ignoreCondition {
+	return func(match Match) bool {
+		for _, upstream := range match.Package.Upstreams {
+			if name == upstream.Name {
+				return true
+			}
+		}
+		return false
+	}
+}
+
+func ifMatchTypeApplies(matchType Type) ignoreCondition {
+	return func(match Match) bool {
+		for _, mType := range match.Details.Types() {
+			if mType == matchType {
+				return true
+			}
+		}
+		return false
+	}
+}
+
 func ruleLocationAppliesToMatch(location string, match Match) bool {
 	for _, packageLocation := range match.Package.Locations.ToSlice() {
 		if ruleLocationAppliesToPath(location, packageLocation.RealPath) {
 			return true
 		}
 
-		if ruleLocationAppliesToPath(location, packageLocation.VirtualPath) {
+		if ruleLocationAppliesToPath(location, packageLocation.AccessPath) {
 			return true
 		}
 	}
