@@ -177,6 +177,7 @@ func distroFeedIsComprehensive(distro *linux.Release) bool {
 // sqlite3 vulnerability.db 'select distinct namespace from vulnerability where fix_state in ("wont-fix", "not-fixed") order by namespace;' | cut -d ':' -f 1 | sort | uniq
 // then removing 'github' and replacing 'redhat' with 'rhel'
 var comprehensiveDistros = []string{
+	"azurelinux",
 	"debian",
 	"mariner",
 	"rhel",
@@ -214,10 +215,27 @@ func dataFromPkg(p pkg.Package) (interface{}, []UpstreamPackage) {
 	case pkg.ApkDBEntry:
 		metadata = apkMetadataFromPkg(p)
 		upstreams = apkDataFromPkg(p)
+	case pkg.JavaVMInstallation:
+		metadata = javaVMDataFromPkg(p)
 	}
 	return metadata, upstreams
 }
 
+func javaVMDataFromPkg(p pkg.Package) any {
+	if value, ok := p.Metadata.(pkg.JavaVMInstallation); ok {
+		return JavaVMInstallationMetadata{
+			Release: JavaVMReleaseMetadata{
+				JavaRuntimeVersion: value.Release.JavaRuntimeVersion,
+				JavaVersion:        value.Release.JavaVersion,
+				FullVersion:        value.Release.FullVersion,
+				SemanticVersion:    value.Release.SemanticVersion,
+			},
+		}
+	}
+
+	return nil
+}
+
 func apkMetadataFromPkg(p pkg.Package) interface{} {
 	if m, ok := p.Metadata.(pkg.ApkDBEntry); ok {
 		metadata := ApkMetadata{}
