@@ -2,6 +2,7 @@ package pkg
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -16,14 +17,6 @@ import (
 	"github.com/anchore/syft/syft/sbom"
 )
 
-type errEmptySBOM struct {
-	sbomFilepath string
-}
-
-func (e errEmptySBOM) Error() string {
-	return fmt.Sprintf("SBOM file is empty: %s", e.sbomFilepath)
-}
-
 func syftSBOMProvider(userInput string, config ProviderConfig) ([]Package, Context, *sbom.SBOM, error) {
 	s, err := getSBOM(userInput)
 	if err != nil {
@@ -83,7 +76,11 @@ func extractReaderAndInfo(userInput string) (io.ReadSeeker, *inputInfo, error) {
 	case userInput == "":
 		// we only want to attempt reading in from stdin if the user has not specified other
 		// options from the CLI, otherwise we should not assume there is any valid input from stdin.
-		return decodeStdin(stdinReader())
+		r, err := stdinReader()
+		if err != nil {
+			return nil, nil, err
+		}
+		return decodeStdin(r)
 
 	case explicitlySpecifyingSBOM(userInput):
 		filepath := strings.TrimPrefix(userInput, "sbom:")
@@ -121,37 +118,17 @@ func decodeStdin(r io.Reader) (io.ReadSeeker, *inputInfo, error) {
 	return reader, newInputInfo("", "sbom"), nil
 }
 
-// fileHasContent returns a bool indicating whether the given file has data that could possibly be utilized in
-// downstream processing.
-func fileHasContent(f *os.File) bool {
-	if f == nil {
-		return false
-	}
-
-	info, err := f.Stat()
-	if err != nil {
-		return false
-	}
-
-	if size := info.Size(); size > 0 {
-		return true
-	}
-
-	return false
-}
-
-func stdinReader() io.Reader {
+func stdinReader() (io.Reader, error) {
 	isStdinPipeOrRedirect, err := internal.IsStdinPipeOrRedirect()
 	if err != nil {
-		log.Warnf("unable to determine if there is piped input: %+v", err)
-		return nil
+		return nil, fmt.Errorf("unable to determine if there is piped input: %w", err)
 	}
 
 	if !isStdinPipeOrRedirect {
-		return nil
+		return nil, errors.New("no input was provided via stdin")
 	}
 
-	return os.Stdin
+	return os.Stdin, nil
 }
 
 func closeFile(f *os.File) {
@@ -176,10 +153,6 @@ func openFile(path string) (*os.File, error) {
 		return nil, fmt.Errorf("unable to open file %s: %w", expandedPath, err)
 	}
 
-	if !fileHasContent(f) {
-		return nil, errEmptySBOM{path}
-	}
-
 	return f, nil
 }
 
