@@ -4,7 +4,6 @@ import (
 	"regexp"
 	"testing"
 
-	grypeDb "github.com/anchore/grype/grype/db/v5"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/presenter/models"
@@ -85,11 +84,13 @@ func generateMatches(t *testing.T, p1, p2 pkg.Package) match.Matches {
 		{
 
 			Vulnerability: vulnerability.Vulnerability{
-				ID:        "CVE-1999-0001",
-				Namespace: "source-1",
+				Reference: vulnerability.Reference{
+					ID:        "CVE-1999-0001",
+					Namespace: "source-1",
+				},
 				Fix: vulnerability.Fix{
 					Versions: []string{"the-next-version"},
-					State:    grypeDb.FixedState,
+					State:    vulnerability.FixStateFixed,
 				},
 			},
 			Package: p1,
@@ -112,8 +113,10 @@ func generateMatches(t *testing.T, p1, p2 pkg.Package) match.Matches {
 		{
 
 			Vulnerability: vulnerability.Vulnerability{
-				ID:        "CVE-1999-0002",
-				Namespace: "source-2",
+				Reference: vulnerability.Reference{
+					ID:        "CVE-1999-0002",
+					Namespace: "source-2",
+				},
 			},
 			Package: p2,
 			Details: []match.Detail{
@@ -144,8 +147,10 @@ func generateIgnoredMatches(t *testing.T, p pkg.Package) []match.IgnoredMatch {
 		{
 			Match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
-					ID:        "CVE-1999-0001",
-					Namespace: "source-1",
+					Reference: vulnerability.Reference{
+						ID:        "CVE-1999-0001",
+						Namespace: "source-1",
+					},
 				},
 				Package: p,
 				Details: []match.Detail{
@@ -169,8 +174,10 @@ func generateIgnoredMatches(t *testing.T, p pkg.Package) []match.IgnoredMatch {
 		{
 			Match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
-					ID:        "CVE-1999-0002",
-					Namespace: "source-2",
+					Reference: vulnerability.Reference{
+						ID:        "CVE-1999-0002",
+						Namespace: "source-2",
+					},
 				},
 				Package: p,
 				Details: []match.Detail{
@@ -191,8 +198,10 @@ func generateIgnoredMatches(t *testing.T, p pkg.Package) []match.IgnoredMatch {
 		{
 			Match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
-					ID:        "CVE-1999-0004",
-					Namespace: "source-2",
+					Reference: vulnerability.Reference{
+						ID:        "CVE-1999-0004",
+						Namespace: "source-2",
+					},
 				},
 				Package: p,
 				Details: []match.Detail{
@@ -251,6 +260,7 @@ func generatePackages(t *testing.T) []syftPkg.Package {
 			Name:      "package-2",
 			Version:   "2.2.2",
 			Type:      syftPkg.DebPkg,
+			PURL:      "pkg:deb/package-2@2.2.2",
 			Locations: file.NewLocationSet(file.NewVirtualLocation("/foo/bar/somefile-2.txt", "somefile-2.txt")),
 			CPEs: []cpe.CPE{
 				{
