@@ -2,13 +2,13 @@ package models
 
 import (
 	"fmt"
+	"sort"
 	"time"
 
+	"github.com/anchore/clio"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
-	"github.com/anchore/grype/internal"
-	"github.com/anchore/grype/internal/version"
 )
 
 // Document represents the JSON document to be presented
@@ -21,7 +21,7 @@ type Document struct {
 }
 
 // NewDocument creates and populates a new Document struct, representing the populated JSON document.
-func NewDocument(packages []pkg.Package, context pkg.Context, matches match.Matches, ignoredMatches []match.IgnoredMatch, metadataProvider vulnerability.MetadataProvider, appConfig interface{}, dbStatus interface{}) (Document, error) {
+func NewDocument(id clio.Identification, packages []pkg.Package, context pkg.Context, matches match.Matches, ignoredMatches []match.IgnoredMatch, metadataProvider vulnerability.MetadataProvider, appConfig interface{}, dbStatus interface{}) (Document, error) {
 	timestamp, timestampErr := time.Now().Local().MarshalText()
 	if timestampErr != nil {
 		return Document{}, timestampErr
@@ -43,6 +43,8 @@ func NewDocument(packages []pkg.Package, context pkg.Context, matches match.Matc
 		findings = append(findings, *matchModel)
 	}
 
+	sort.Sort(MatchSort(findings))
+
 	var src *source
 	if context.Source != nil {
 		theSrc, err := newSource(*context.Source)
@@ -77,8 +79,8 @@ func NewDocument(packages []pkg.Package, context pkg.Context, matches match.Matc
 		Source:         src,
 		Distro:         newDistribution(context.Distro),
 		Descriptor: descriptor{
-			Name:                  internal.ApplicationName,
-			Version:               version.FromBuild().Version,
+			Name:                  id.Name,
+			Version:               id.Version,
 			Configuration:         appConfig,
 			VulnerabilityDBStatus: dbStatus,
 			Timestamp:             string(timestamp),
