@@ -35,3 +35,23 @@ func NewVulnerabilityMetadata(id, namespace string, metadata *vulnerability.Meta
 		Cvss:        NewCVSS(metadata),
 	}
 }
+
+// returns severtiy score for presenter sorting purposes
+func SeverityScore(severtiy string) int {
+	switch severtiy {
+	case "Unknown":
+		return 0
+	case "Negligible":
+		return 1
+	case "Low":
+		return 2
+	case "Medium":
+		return 3
+	case "High":
+		return 4
+	case "Critical":
+		return 5
+	default:
+		return 0
+	}
+}
