@@ -6,7 +6,6 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	v5 "github.com/anchore/grype/grype/db/v5"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
@@ -43,11 +42,13 @@ func TestProcessor_ApplyVEX(t *testing.T) {
 
 	libCryptoCVE_2023_3817 := match.Match{
 		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-2023-3817",
-			Namespace: "alpine:distro:alpine:3.17",
+			Reference: vulnerability.Reference{
+				ID:        "CVE-2023-3817",
+				Namespace: "alpine:distro:alpine:3.17",
+			},
 			Fix: vulnerability.Fix{
 				Versions: []string{"3.0.10-r0"},
-				State:    v5.FixedState,
+				State:    vulnerability.FixStateFixed,
 			},
 		},
 		Package: libCryptoPackage,
@@ -55,11 +56,13 @@ func TestProcessor_ApplyVEX(t *testing.T) {
 
 	libCryptoCVE_2023_1255 := match.Match{
 		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-2023-1255",
-			Namespace: "alpine:distro:alpine:3.17",
+			Reference: vulnerability.Reference{
+				ID:        "CVE-2023-1255",
+				Namespace: "alpine:distro:alpine:3.17",
+			},
 			Fix: vulnerability.Fix{
 				Versions: []string{"3.0.8-r4"},
-				State:    v5.FixedState,
+				State:    vulnerability.FixStateFixed,
 			},
 		},
 		Package: libCryptoPackage,
@@ -67,11 +70,13 @@ func TestProcessor_ApplyVEX(t *testing.T) {
 
 	libCryptoCVE_2023_2975 := match.Match{
 		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-2023-2975",
-			Namespace: "alpine:distro:alpine:3.17",
+			Reference: vulnerability.Reference{
+				ID:        "CVE-2023-2975",
+				Namespace: "alpine:distro:alpine:3.17",
+			},
 			Fix: vulnerability.Fix{
 				Versions: []string{"3.0.9-r2"},
-				State:    v5.FixedState,
+				State:    vulnerability.FixStateFixed,
 			},
 		},
 		Package: libCryptoPackage,
