@@ -1,18 +1,18 @@
 package integration
 
 import (
-	grypeDB "github.com/anchore/grype/grype/db/v5"
+	v5 "github.com/anchore/grype/grype/db/v5"
 )
 
 // integrity check
-var _ grypeDB.VulnerabilityStoreReader = &mockStore{}
+var _ v5.VulnerabilityStoreReader = &mockStore{}
 
 type mockStore struct {
 	normalizedPackageNames map[string]map[string]string
-	backend                map[string]map[string][]grypeDB.Vulnerability
+	backend                map[string]map[string][]v5.Vulnerability
 }
 
-func (s *mockStore) GetVulnerability(namespace, id string) ([]grypeDB.Vulnerability, error) {
+func (s *mockStore) GetVulnerability(namespace, id string) ([]v5.Vulnerability, error) {
 	// TODO implement me
 	panic("implement me")
 }
@@ -26,7 +26,7 @@ func (s *mockStore) GetVulnerabilityNamespaces() ([]string, error) {
 	return results, nil
 }
 
-func (s *mockStore) GetVulnerabilityMatchExclusion(id string) ([]grypeDB.VulnerabilityMatchExclusion, error) {
+func (s *mockStore) GetVulnerabilityMatchExclusion(id string) ([]v5.VulnerabilityMatchExclusion, error) {
 	return nil, nil
 }
 
@@ -34,16 +34,25 @@ func newMockDbStore() *mockStore {
 	return &mockStore{
 		normalizedPackageNames: map[string]map[string]string{
 			"github:language:python": {
-				"Pygments":   "pygments",
+				"pygments":   "pygments",
 				"my-package": "my-package",
 			},
 			"github:language:dotnet": {
 				"AWSSDK.Core": "awssdk.core",
 			},
 		},
-		backend: map[string]map[string][]grypeDB.Vulnerability{
+		backend: map[string]map[string][]v5.Vulnerability{
 			"nvd:cpe": {
-				"libvncserver": []grypeDB.Vulnerability{
+				"jdk": []v5.Vulnerability{
+					{
+						ID:                "CVE-jdk",
+						PackageName:       "jdk",
+						VersionConstraint: "< 1.8.0_401",
+						VersionFormat:     "jvm",
+						CPEs:              []string{"cpe:2.3:a:oracle:jdk:*:*:*:*:*:*:*:*"},
+					},
+				},
+				"libvncserver": []v5.Vulnerability{
 					{
 						ID:                "CVE-alpine-libvncserver",
 						VersionConstraint: "< 0.9.10",
@@ -51,7 +60,7 @@ func newMockDbStore() *mockStore {
 						CPEs:              []string{"cpe:2.3:a:lib_vnc_project-(server):libvncserver:*:*:*:*:*:*:*:*"},
 					},
 				},
-				"my-package": []grypeDB.Vulnerability{
+				"my-package": []v5.Vulnerability{
 					{
 						ID:                "CVE-bogus-my-package-1",
 						VersionConstraint: "< 2.0",
@@ -67,21 +76,21 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"alpine:distro:alpine:3.12": {
-				"libvncserver": []grypeDB.Vulnerability{
+				"libvncserver": []v5.Vulnerability{
 					{
 						ID:                "CVE-alpine-libvncserver",
 						VersionConstraint: "< 0.9.10",
 						VersionFormat:     "unknown",
 					},
 				},
-				"ko": []grypeDB.Vulnerability{
+				"ko": []v5.Vulnerability{
 					{
 						ID:                "CVE-azure-autorest-vuln-false-positive",
 						VersionConstraint: "< 0",
 						VersionFormat:     "apk",
 					},
 				},
-				"npm-apk-package-with-false-positive": []grypeDB.Vulnerability{
+				"npm-apk-package-with-false-positive": []v5.Vulnerability{
 					{
 						ID:                "CVE-npm-false-positive-in-apk-subpackage",
 						VersionConstraint: "< 0",
@@ -90,7 +99,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"gentoo:distro:gentoo:2.8": {
-				"app-containers/skopeo": []grypeDB.Vulnerability{
+				"app-containers/skopeo": []v5.Vulnerability{
 					{
 						ID:                "CVE-gentoo-skopeo",
 						VersionConstraint: "< 1.6.0",
@@ -99,21 +108,21 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:go": {
-				"github.com/anchore/coverage": []grypeDB.Vulnerability{
+				"github.com/anchore/coverage": []v5.Vulnerability{
 					{
 						ID:                "CVE-coverage-main-module-vuln",
 						VersionConstraint: "< 1.4.0",
 						VersionFormat:     "unknown",
 					},
 				},
-				"github.com/google/uuid": []grypeDB.Vulnerability{
+				"github.com/google/uuid": []v5.Vulnerability{
 					{
 						ID:                "CVE-uuid-vuln",
 						VersionConstraint: "< 1.4.0",
 						VersionFormat:     "unknown",
 					},
 				},
-				"github.com/azure/go-autorest/autorest": []grypeDB.Vulnerability{
+				"github.com/azure/go-autorest/autorest": []v5.Vulnerability{
 					{
 						ID:                "CVE-azure-autorest-vuln-false-positive",
 						VersionConstraint: "< 0.11.30",
@@ -122,7 +131,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:idris": {
-				"my-package": []grypeDB.Vulnerability{
+				"my-package": []v5.Vulnerability{
 					{
 						ID:                "CVE-bogus-my-package-2-idris",
 						VersionConstraint: "< 2.0",
@@ -131,14 +140,14 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:javascript": {
-				"npm": []grypeDB.Vulnerability{
+				"npm": []v5.Vulnerability{
 					{
 						ID:                "CVE-javascript-validator",
 						VersionConstraint: "> 5, < 7.2.1",
 						VersionFormat:     "unknown",
 					},
 				},
-				"npm-apk-subpackage-with-false-positive": []grypeDB.Vulnerability{
+				"npm-apk-subpackage-with-false-positive": []v5.Vulnerability{
 					{
 						ID:                "CVE-npm-false-positive-in-apk-subpackage",
 						VersionConstraint: "< 2.0.0",
@@ -147,16 +156,17 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:python": {
-				"pygments": []grypeDB.Vulnerability{
+				"pygments": []v5.Vulnerability{
 					{
 						ID:                "CVE-python-pygments",
 						VersionConstraint: "< 2.6.2",
 						VersionFormat:     "python",
 					},
 				},
+				"my-package": []v5.Vulnerability{},
 			},
 			"github:language:ruby": {
-				"bundler": []grypeDB.Vulnerability{
+				"bundler": []v5.Vulnerability{
 					{
 						ID:                "CVE-ruby-bundler",
 						VersionConstraint: "> 2.0.0, <= 2.1.4",
@@ -165,7 +175,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:java": {
-				"org.anchore:example-java-app-maven": []grypeDB.Vulnerability{
+				"org.anchore:example-java-app-maven": []v5.Vulnerability{
 					{
 						ID:                "CVE-java-example-java-app",
 						VersionConstraint: ">= 0.0.1, < 1.2.0",
@@ -174,7 +184,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:dotnet": {
-				"awssdk.core": []grypeDB.Vulnerability{
+				"awssdk.core": []v5.Vulnerability{
 					{
 						ID:                "CVE-dotnet-sample",
 						VersionConstraint: ">= 3.7.0.0, < 3.7.12.0",
@@ -183,7 +193,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:haskell": {
-				"shellcheck": []grypeDB.Vulnerability{
+				"shellcheck": []v5.Vulnerability{
 					{
 						ID:                "CVE-haskell-sample",
 						VersionConstraint: "< 0.9.0",
@@ -192,14 +202,14 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"github:language:rust": {
-				"hello-auditable": []grypeDB.Vulnerability{
+				"hello-auditable": []v5.Vulnerability{
 					{
 						ID:                "CVE-rust-sample-1",
 						VersionConstraint: "< 0.2.0",
 						VersionFormat:     "unknown",
 					},
 				},
-				"auditable": []grypeDB.Vulnerability{
+				"auditable": []v5.Vulnerability{
 					{
 						ID:                "CVE-rust-sample-2",
 						VersionConstraint: "< 0.2.0",
@@ -208,7 +218,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"debian:distro:debian:8": {
-				"apt-dev": []grypeDB.Vulnerability{
+				"apt-dev": []v5.Vulnerability{
 					{
 						ID:                "CVE-dpkg-apt",
 						VersionConstraint: "<= 1.8.2",
@@ -217,7 +227,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"redhat:distro:redhat:8": {
-				"dive": []grypeDB.Vulnerability{
+				"dive": []v5.Vulnerability{
 					{
 						ID:                "CVE-rpmdb-dive",
 						VersionConstraint: "<= 1.0.42",
@@ -226,7 +236,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"msrc:distro:windows:10816": {
-				"10816": []grypeDB.Vulnerability{
+				"10816": []v5.Vulnerability{
 					{
 						ID:                "CVE-2016-3333",
 						VersionConstraint: "3200970 || 878787 || base",
@@ -235,7 +245,7 @@ func newMockDbStore() *mockStore {
 				},
 			},
 			"sles:distro:sles:12.5": {
-				"dive": []grypeDB.Vulnerability{
+				"dive": []v5.Vulnerability{
 					{
 						ID:                "CVE-rpmdb-dive",
 						VersionConstraint: "<= 1.0.42",
@@ -247,7 +257,7 @@ func newMockDbStore() *mockStore {
 	}
 }
 
-func (s *mockStore) SearchForVulnerabilities(namespace, name string) ([]grypeDB.Vulnerability, error) {
+func (s *mockStore) SearchForVulnerabilities(namespace, name string) ([]v5.Vulnerability, error) {
 	namespaceMap := s.backend[namespace]
 	if namespaceMap == nil {
 		return nil, nil
@@ -262,14 +272,14 @@ func (s *mockStore) SearchForVulnerabilities(namespace, name string) ([]grypeDB.
 	return entries, nil
 }
 
-func (s *mockStore) GetAllVulnerabilities() (*[]grypeDB.Vulnerability, error) {
+func (s *mockStore) GetAllVulnerabilities() (*[]v5.Vulnerability, error) {
 	return nil, nil
 }
 
-func (s *mockStore) GetVulnerabilityMetadata(id string, namespace string) (*grypeDB.VulnerabilityMetadata, error) {
+func (s *mockStore) GetVulnerabilityMetadata(id string, namespace string) (*v5.VulnerabilityMetadata, error) {
 	return nil, nil
 }
 
-func (s *mockStore) GetAllVulnerabilityMetadata() (*[]grypeDB.VulnerabilityMetadata, error) {
+func (s *mockStore) GetAllVulnerabilityMetadata() (*[]v5.VulnerabilityMetadata, error) {
 	return nil, nil
 }
